Hello World Example
===============================================================================

:download:`hello_world.enaml <../../../examples/hello_world/hello_world.enaml>`

.. literalinclude:: ../../../examples/hello_world/hello_world.enaml
    :language: python

:download:`hello_world.py<../../../examples/hello_world/hello_world.py>`

.. literalinclude:: ../../../examples/hello_world/hello_world.py
    :language: python

::

 $ python hello_world.py

.. image:: images/hello_world.png
